@@ -222,7 +222,7 @@ url: %s
 				}
 
 				// Decode the JSON to a map[string]interface{} and then unmarshal it again to the correct format.
-				var m map[string]interface{}
+				var m map[string]any
 				if err := json.Unmarshal(buf.Bytes(), &m); err != nil {
 					return err
 				}
