@@ -45,6 +45,7 @@ import (
 	"github.com/gohugoio/hugo/tpl"
 	"github.com/mitchellh/mapstructure"
 	"github.com/spf13/cast"
+	maps0 "maps"
 )
 
 const (
@@ -696,9 +697,7 @@ func (c *cachedContentScope) contentToC(ctx context.Context) (contentTableOfCont
 			cp.otherOutputs.Set(cp2.po.p.pid, cp2)
 
 			// Merge content placeholders
-			for k, v := range ct2.contentPlaceholders {
-				ct.contentPlaceholders[k] = v
-			}
+			maps0.Copy(ct.contentPlaceholders, ct2.contentPlaceholders)
 
 			if p.s.conf.Internal.Watch {
 				for _, s := range cp2.po.p.m.content.shortcodeState.shortcodes {
@@ -730,16 +729,15 @@ func (c *cachedContentScope) contentToC(ctx context.Context) (contentTableOfCont
 		isHTML := cp.po.p.m.pageConfig.ContentMediaType.IsHTML()
 
 		if !isHTML {
-			createAndSetToC := func(tocProvider converter.TableOfContentsProvider) {
+			createAndSetToC := func(tocProvider converter.TableOfContentsProvider) error {
 				cfg := p.s.ContentSpec.Converters.GetMarkupConfig()
 				ct.tableOfContents = tocProvider.TableOfContents()
-				ct.tableOfContentsHTML = template.HTML(
-					ct.tableOfContents.ToHTML(
-						cfg.TableOfContents.StartLevel,
-						cfg.TableOfContents.EndLevel,
-						cfg.TableOfContents.Ordered,
-					),
+				ct.tableOfContentsHTML, err = ct.tableOfContents.ToHTML(
+					cfg.TableOfContents.StartLevel,
+					cfg.TableOfContents.EndLevel,
+					cfg.TableOfContents.Ordered,
 				)
+				return err
 			}
 
 			// If the converter supports doing the parsing separately, we do that.
