@@ -27,8 +27,6 @@ import (
 	"github.com/gohugoio/hugo/markup/converter"
 	xmaps "golang.org/x/exp/maps"
 
-	"github.com/gohugoio/hugo/related"
-
 	"github.com/gohugoio/hugo/source"
 
 	"github.com/gohugoio/hugo/common/constants"
@@ -215,16 +213,6 @@ func (p *pageMeta) PathInfo() *paths.Path {
 	return p.pathInfo
 }
 
-// RelatedKeywords implements the related.Document interface needed for fast page searches.
-func (p *pageMeta) RelatedKeywords(cfg related.IndexConfig) ([]related.Keyword, error) {
-	v, err := p.Param(cfg.Name)
-	if err != nil {
-		return nil, err
-	}
-
-	return cfg.ToKeywords(v)
-}
-
 func (p *pageMeta) IsSection() bool {
 	return p.Kind() == kinds.KindSection
 }
@@ -430,6 +418,7 @@ func (p *pageState) setMetaPostParams() error {
 	var buildConfig any
 	var isNewBuildKeyword bool
 	if v, ok := pm.pageConfig.Params["_build"]; ok {
+		hugo.Deprecate("The \"_build\" front matter key", "Use \"build\" instead. See https://gohugo.io/content-management/build-options.", "0.145.0")
 		buildConfig = v
 	} else {
 		buildConfig = pm.pageConfig.Params["build"]
