@@ -250,7 +250,7 @@ Content.
 Base %d: {{ block "main" . }}FOO{{ end }}
 `
 
-	for i := 0; i < numPages; i++ {
+	for i := range numPages {
 		id := i + 1
 		b.WithContent(fmt.Sprintf("page%d.md", id), fmt.Sprintf(pageTemplate, id, id))
 		b.WithTemplates(fmt.Sprintf("_default/layout%d.html", id), fmt.Sprintf(singleTemplate, id))
@@ -258,7 +258,7 @@ Base %d: {{ block "main" . }}FOO{{ end }}
 	}
 
 	b.Build(BuildCfg{})
-	for i := 0; i < numPages; i++ {
+	for i := range numPages {
 		id := i + 1
 		b.AssertFileContent(fmt.Sprintf("public/page%d/index.html", id), fmt.Sprintf(`Base %d: %d`, id, id))
 	}
